---
name: Bug Report
about: Document a problem
title: ''
labels: ''
assignees: ''

---

**Description**

Describe the issue.

**Example**

Provide an interactive Python session, or Python code, to demonstrate the issue. Please keep example data to a minimum.

```python

```

**Platform**

Run the following function (static-frame >= 0.8.1) and provide the results to define your platform and environment:

```python
>>> import static_frame as sf
>>> sf.Platform.display()
```